@@ -1,8 +1,8 @@
 package AFS::Cell;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$RCS-Id: src/Cell/Cell.pm 7a64d4d Wed May 1 22:05:49 2013 +0200 Norbert E Gruener$"
+# RCS-Id: "@(#)Cell.pm,v 2.0 2002/07/02 06:12:14 nog Exp"
 #
-# © 2001-2010 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
@@ -17,12 +17,13 @@ require Exporter;
 @EXPORT_OK = qw(
                 configdir
                 expandcell
+                getcell
                 getcellinfo
                 localcell
                 whichcell
                 wscell
                );
-@ISA     = qw(Exporter AFS);
-$VERSION = 'v2.6.4';
+@ISA       = qw(Exporter AFS);
+$VERSION   = sprintf("%d.%02d", q/2.0/ =~ /(\d+)\.(\d+)/);
 
 1;
